#!/bin/bash
    
#	Megaupload script make your downloads easier from http://www.megaupload.com
#	Copyright (C) 2008  Aurélien Dominguez tenkaistar@gmail.com
#
#	This program is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program.  If not, see <http://www.gnu.org/licenses/>.

if [ -f "$HOME/.megaup.conf" ]
then	. $HOME/.megaup.conf
else	echo "Configuration file is missing, please copy the .megaup.conf file provided in the script package to $HOME/.megaup.conf and edit it accordingly to your setup."
	exit 3
fi

if  [ -d $tmpdir ]
then 	echo "" > /dev/null
else 	mkdir $tmpdir
fi
	
if [ -d $dldir ]
then	echo "" > /dev/null
else 	mkdir $dldir
fi

codedl=$1

if [ "echo $codedl | grep -i ^http" ]
then
	codedl=`echo $codedl | cut -d= -f2`
fi

date=`date`
echo "$date: Starting process for $codedl ..."

logfile="$tmpdir/$codedl.log"


if [ -f $logfile ]
then	rm $logfile
fi

touch "$logfile"

# First step checks if requested file exists. If file exists, retry until check code works.
firststep='0'
while [ "$firststep" != "1" ]
do
	$wget --quiet "http://www.megaupload.com/?d=$codedl" -O "$tmpdir/$codedl.html" -o "$logfile"
	cat "$tmpdir/$codedl.html" | grep --silent -i '<div id="error">'
	
	returncode=$?

	if [ "$returncode" -eq "0" ]
	then	echo "File $codedl doesn't exist"
		exit 1	# Requested file doesn't exist, exit script returning 1 as exit code
	fi

	capgen=`cat $tmpdir/$codedl.html | grep capgen.php | cut -d\" -f4 | cut -d? -f2`

	$wget --quiet "http://www.megaupload.com/capgen.php?$capgen" -O "$tmpdir/$codedl.gif"

	imagestring=`$getimgstring $tmpdir/$codedl.gif` # running character detection script

	d=$codedl
	imagecode=`cat $tmpdir/$codedl.html | grep -i imagecode | cut -d\" -f6`
	megavar=`cat $tmpdir/$codedl.html | grep -i megavar | cut -d\" -f6`

	$wget --quiet --post-data "d=$d&imagecode=$imagecode&megavar=$megavar&imagestring=$imagestring" "http://www.megaupload.com/fr/" -O "$tmpdir/$codedl.html" -o "$logfile"
	
	cat $tmpdir/$codedl.html | grep -i --silent 'id="captchafrm">'

	returncode=$?

	if [ "$returncode" -ne "0" ]	# If authentication did not work, retry
	then	firststep="1"
	fi
done

# Second step builds file URL 

linkparts=`cat "$tmpdir/$codedl.html"  | grep -i megaupload.com/files`

linkpart1=`echo $linkparts | cut -d\  -f4 | cut -d\" -f2 | cut -d\' -f1`
linkpart4=`echo $linkparts | cut -d\  -f10 | cut -d\' -f2 | cut -d\" -f1`

var1=`cat "$tmpdir/$codedl.html" |  grep -i  "Math.abs" | cut -d\- -f2 | cut -d\) -f1`
var2=`cat "$tmpdir/$codedl.html" | grep -i  "Math.sqrt" | cut -d\( -f3 | cut -d\) -f1`
rdmletter=`cat "$tmpdir/$codedl.html" | grep -i  "Math.sqrt" | cut -d\' -f2`

var2=`bc -l << EOF
scale = 0
sqrt($var2)
EOF`



var1=`$dec2ascii $var1`	
var2=`$dec2ascii $var2`	

linkpart2=$rdmletter$var2
linkpart3=$var1

dlink="$linkpart1$linkpart2$linkpart3$linkpart4" # Putting all parts together to build file URL 

filename=`echo "$dlink" | cut -d\/ -f6"`

echo $dlink

sleep 45	# Waiting 45 seconds before starting download since server wait 45 secs to create link to the file on the server for non-member users

if [ -f $logfile ]
then rm $logfile
fi

touch $logfile

echo "Starting $filename download. It will be saved in $dldir. To view download progress use following command: cat $logfile"

$wget -c $dlink -P "$dldir" -o $logfile
returncode=$?

if [ "$returncode" != "0" ]
then	cat $logfile | grep -i --silent "Limit Exceeded"
	returncode=$?
	if [ "$returncode" == "0" ]
	then	echo "Limit Exceeded"
		exit 2	
	fi
fi
rm -R $tmpdir

date=`date`
echo "$date: $codedl download finished"
exit 0
